I/O — aeolus 0.4.9+9.g5a71939.dirty documentation

# I/O

Input and output utilities.

aeolus.io.load_multidir(path_mask, labels, label_name='run')

  Load cubelists from multiple directories and merge.

aeolus.io.load_vert_lev(path_to_file, lev_type='theta')

  Read data from the UM vertical levels file.

  Parameters

    - path_to_file (pathlib.Path) – Full path to the vertical levels file.

    - lev_type (str, optional) – What levels to return: “theta” or “rho”.

  Returns

    levs – Array of height levels.

  Return type

    numpy.array